<template>
  <div class="info-company">
    <div class="header">
      <div class="title">
        <i class="icon"></i>
        <span class="name">{{ title }}</span>
      </div>
    </div>
    <div class="content">
      <div class="info">
        <div class="return" @click="returnPreInfo">&lt; 返回{{ returnName }}信息</div>
        <div class="detail">
          <span class="label">法定代表人：</span>
          <span class="value">{{ legal }}</span>
        </div>
        <div class="detail">
          <span class="label">联系方式：</span>
          <span v-if="!concatVisible" class="value">{{ contactHide }}</span>
          <span v-if="concatVisible" class="value">{{ legalContact }}</span>
          <span class="visible" @click="concatVisible = !concatVisible">{{ contactVisibleName }}</span>
        </div>
        <div class="detail">
          <span class="label">注册地址：</span>
          <span class="value">{{ registerAddress }}</span>
        </div>
        <div class="detail">
          <span class="label">驻勤点数：</span>
          <span class="value">{{ countOfActivityStation }}</span>
        </div>
        <div class="detail">
          <span class="label">保安员数：</span>
          <span class="value">{{ countOfSecurityMan }}</span>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
export default {
  name: "infoCompany",
  props: {
    data: Object,
  },
  data() {
    return {
      concatVisible: false,
    };
  },
  computed: {
    title() {
      return `${this.data?.name}`;
    },
    returnName() {
      switch (this.data.returnWin) {
        case "employee":
          return "安保员";
        case "station":
          return "驻勤点";
        default:
          return "";
      }
    },
    legal() {
      return this.data?.legal || ";";
    },
    contactHide() {
      return "***********";
    },
    legalContact() {
      return this.data?.legalContact || "";
    },
    contactVisibleName() {
      return this.concatVisible ? "隐藏" : "显示";
    },
    registerAddress() {
      return this.data?.registerAddress || "";
    },
    countOfActivityStation() {
      return this.data?.countOfActivityStation || 0;
    },
    countOfSecurityMan() {
      return this.data?.countOfSecurityMan || 0;
    },
  },
  methods: {
    returnPreInfo() {
      this.$emit("return", this.data.returnDetail, this.data.returnWin);
    },
  },
};
</script>

<style scoped lang="less">
.info-company {
  .header {
    width: 100%;
    height: 71px;
    background: #ffffff;
    padding: 0 20px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    //justify-content: space-between;
    .title {
      display: flex;
      align-items: center;
      .icon {
        display: block;
        width: 40px;
        height: 40px;
        background: url("~@/assets/images/mapSearch/搜地址.png") no-repeat;
        background-size: 100% 100%;
      }
      .name {
        font-size: 14px;
        font-family: PingFang SC-Medium, PingFang SC;
        font-weight: 500;
        color: #303133;
        line-height: 22px;
        margin-left: 8px;
      }
    }
  }
  .content {
    width: 100%;
    .info {
      width: 100%;
      padding: 12px 20px;
      .return {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC;
        font-weight: 400;
        color: #0f71ff;
        line-height: 22px;
        margin-bottom: 10px;
      }
      .detail {
        width: 100%;
        display: flex;
        align-items: center;
        margin-bottom: 10px;
        &:last-child {
          margin-bottom: 0;
        }
        .label {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #909399;
        }

        .value {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC;
          font-weight: 400;
          color: #303133;
          &-link {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC;
            font-weight: 400;
            color: #0f71ff;
            text-decoration: underline;
          }
        }
        .visible {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC;
          font-weight: 400;
          color: #0f71ff;
          margin-left: 2px;
        }
      }
    }
  }
}
</style>
